@@ -21,9 +21,8 @@ import ipywidgets as widgets
 # Establece las variables globales
 # Código HTML para la pestaña de instrucciones 
 instructions_html = None 
-path = pkgutil.get_data(__name__, "instructions.html")
-with open(path, 'r') as file:
-    instructions_html = file.read()
+data = pkgutil.get_data(__name__, "instructions.html")
+instructions_html = data.decode('utf-8')
 
 __DEBUG__ = False
 
